@@ -1,6 +1,6 @@
 #include <Rcpp.h>
 #include <pegtl.hpp>
-using namespace tao::TAOCPP_PEGTL_NAMESPACE;
+using namespace tao::TAO_PEGTL_NAMESPACE;
 
 namespace double_
 {
